@@ -26,25 +26,19 @@
 
 ;;; Code:
 
-;; silence byte-compiler
-(defvar yeetube-ytdlp-program)
-(defvar yeetube-torsocks-program)
-
-(defcustom yeetube-mpv-program (executable-find "mpv")
-  "Path for mpv executable."
-  :type 'string
-  :group 'yeetube)
-
 (defcustom yeetube-mpv-enable-torsocks nil
   "Enable torsocks."
   :type 'boolean
   :group 'yeetube)
 
-(defcustom yeetube-mpv-additional-flags nil
+(defcustom yeetube-mpv-additional-flags '("")
   "Additional flags to pass to mpv."
   :type '(repeat string)
   :group 'yeetube)
 
+(defvar yeetube-mpv-torsocks (executable-find "torsocks")
+  "Path to torsocks executable.")
+
 (defvar yeetube-mpv-video-quality "720"
   "Video resolution/quality.
 Accepted values include: 1080, 720, 480, 360, 240, 144")
@@ -68,15 +62,16 @@ Accepted values include: 1080, 720, 480, 360, 240, 144")
 (defun yeetube-mpv-toggle-torsocks ()
   "Toggle torsocks."
   (interactive)
-  (pcase yeetube-mpv-enable-torsocks
-    ('t (setf yeetube-mpv-enable-torsocks nil)
+  (pcase yeetube-mpv-torsocks
+    ('t (setf yeetube-mpv-torsocks nil)
 	(message "yeetube: Torsocks disabled"))
-    ('nil (setf yeetube-mpv-enable-torsocks t)
+    ('nil (setf yeetube-mpv-torsocks t)
 	  (message "yeetube: Torsocks enabled"))))
 
 (defun yeetube-mpv-check ()
   "Check if mpv and yt-dlp is installed."
-  (unless (and yeetube-mpv-program yeetube-ytdlp-program)
+  (unless (and (executable-find "mpv")
+	       (executable-find "yt-dlp"))
     (error "Unable to play video.  Please install `yt-dlp' and `mpv'")))
 
 (defun yeetube-mpv-process (command)
@@ -98,27 +93,25 @@ Accepted values include: 1080, 720, 480, 360, 240, 144")
 (defun yeetube-mpv-play (input &optional info)
   "Start yeetube process to play INPUT using mpv.
 
-INPUT can be a URL or a local file path.
-INFO is optional information to display with `yeetube-mpv-modeline-mode'.
+INFO: Information to display with `yeetube-mpv-modeline-mode'
 
-This function is not specific to just playing URLs.  Feel free to use
-it to play local files."
-  (let* ((yeetube-command
-	  (concat (when yeetube-mpv-enable-torsocks (concat yeetube-torsocks-program " "))
-		  yeetube-mpv-program " --ytdl-format="
+This function is not specific to just playing urls.  Feel free to use
+to play local files."
+  (let* ((yeetube-mpv-path (executable-find "mpv"))
+	 (yeetube-command
+	  (concat (when yeetube-mpv-enable-torsocks (concat yeetube-mpv-torsocks " "))
+		  yeetube-mpv-path " --ytdl-format="
 		  (yeetube-mpv-ytdl-format-video-quality yeetube-mpv-video-quality)
 		  " "
 		  (shell-quote-argument input)
-		  (if yeetube-mpv-additional-flags
-		      (concat " " (mapconcat #'identity yeetube-mpv-additional-flags " "))
-		    ""))))
-    (let ((proc (yeetube-mpv-process yeetube-command)))
-      (message "Yeetube command: %s" yeetube-command)
-      (message (if yeetube-mpv-enable-torsocks
-		   "yeetube: Starting mpv process (Using Torsocks)"
-		 "yeetube: Starting mpv process"))
-      (setf yeetube-mpv-currently-playing (format "[%s]" info))
-      proc)))
+		  " "
+		  (mapconcat #'identity yeetube-mpv-additional-flags " "))))
+    (yeetube-mpv-process yeetube-command)
+    (message "Yeetube command: %s" yeetube-command)
+    (message (if yeetube-mpv-enable-torsocks
+		 "yeetube: Starting mpv process (Using Torsocks)"
+	       "yeetube: Starting mpv process"))
+    (setf yeetube-mpv-currently-playing (format "[%s]" info))))
 
 (define-minor-mode yeetube-mpv-modeline-mode
   "Minor mode for showing currently playing information on the modeline.
