@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "yeetube" "2.1.12"
+(define-package "yeetube" "20251028.1659"
   "Scrape YouTube, Play with mpv & Download with yt-dlp."
   '((emacs  "27.2")
     (compat "29.1.4.2"))
   :url "https://thanosapollo.org/projects/yeetube/"
-  :commit "77e816972a70db86ad06ef10db56e0d8cecede5c"
-  :revdesc "77e816972a70"
+  :commit "02bc06de12e1ff4786a15ec9aa17d6c568c8e42a"
+  :revdesc "02bc06de12e1"
   :keywords '("extensions" "youtube" "videos")
   :authors '(("Thanos Apollo" . "public@thanosapollo.org"))
   :maintainers '(("Thanos Apollo" . "public@thanosapollo.org")))
