@@ -5,8 +5,8 @@
 ;; Author: Thanos Apollo <public@thanosapollo.org>
 ;; Keywords: extensions youtube videos
 ;; URL: https://thanosapollo.org/projects/yeetube/
-;; Package-Version: 2.1.12
-;; Package-Revision: 77e816972a70
+;; Package-Version: 20251028.1659
+;; Package-Revision: 02bc06de12e1
 
 ;; Package-Requires: ((emacs "27.2") (compat "29.1.4.2"))
 
@@ -39,7 +39,6 @@
 ;;; Code:
 
 (require 'compat)
-(require 'image)
 (require 'url)
 (require 'tabulated-list)
 (require 'cl-lib)
@@ -55,16 +54,6 @@
   :group 'external
   :prefix "yeetube-")
 
-(defcustom yeetube-torsocks-program (executable-find "torsocks")
-  "Path for torsocks executable."
-  :type 'string
-  :group 'yeetube)
-
-(defcustom yeetube-ytdlp-program (executable-find "yt-dlp")
-  "Path for yt-dlp executable."
-  :type 'string
-  :group 'yeetube)
-
 (defcustom yeetube-results-limit 20
   "Define a limit for search results."
   :type 'number
@@ -89,7 +78,7 @@
   :group 'yeetube)
 
 (defcustom yeetube-download-directory (or (xdg-user-dir "DOWNLOAD") (getenv "HOME"))
-  "Default directory to download videos."
+  "Default directory to downlaod videos."
   :type 'string
   :group 'yeetube)
 
@@ -141,7 +130,7 @@ Valid options include:
   :prefix 'yeetube-face)
 
 (defcustom yeetube-thumbnail-size '(120 . 90)
-  "Thumbnail size (width . height)."
+  "Thumbnail size (height width)."
   :type '(cons integer integer)
   :group 'yeetube)
 
@@ -182,7 +171,7 @@ Valid options include:
 
 (defvar yeetube-invidious-instances
   '("vid.puffyan.us" "inv.nadeko.net" "invidious.flokinet.to")
-  "List of invidious instances.")
+  "List of invidious instaces.")
 
 (defvar yeetube-content nil
   "Scraped content.")
@@ -216,7 +205,8 @@ videos from.")
 (defun yeetube-get-url (&optional id type)
   "Get video or playlist url for entry ID, adjusted for TYPE."
   ;; When point is on thumbnail, id will be nil.
-  (let* ((id (or id (tabulated-list-get-id)))
+  (let* ((id (or id (tabulated-list-get-id)
+		 (save-excursion (end-of-line) (tabulated-list-get-id))))
 	 (entry (cadr (assoc id yeetube-content)))
 	 (type (or type (aref entry (- (length entry) 1)))))
     (format "%s%s" (if (eq type 'video)
@@ -228,7 +218,8 @@ videos from.")
 (defun yeetube-play ()
   "Play video at point in *yeetube* buffer."
   (interactive)
-  (let* ((id (tabulated-list-get-id))
+  (let* ((id (or (tabulated-list-get-id) (save-excursion (end-of-line)
+							 (tabulated-list-get-id))))
 	 (entry-content (cadr (assoc id yeetube-content)))
 	 (video-url (yeetube-get-url id))
 	 (video-title (aref entry-content (if yeetube-display-thumbnails-p 1 0)))
@@ -300,6 +291,7 @@ If ARG is non-nil, save as a playlist URL."
     (message "Playing: %s" (car (assoc video yeetube-saved-videos)))))
 
 ;;;###autoload
+
 (defun yeetube-remove-saved-video ()
   "Select video to remove from saved videos."
   (interactive)
@@ -309,23 +301,25 @@ If ARG is non-nil, save as a playlist URL."
 
 ;;;###autoload
 (defun yeetube-remove-all-saved-videos ()
-  "Clear all saved videos from yeetube."
+  "Clear yeetube saved."
   (interactive)
   (let ((clear-saved (y-or-n-p "Delete saved?")))
     (when clear-saved
       (setf yeetube-saved-videos nil))))
 
 (defun yeetube-update-saved-videos-list (_symbol new-value _where _environment)
-  "Update saved videos list file.
+  "Updated saved videos.
 
-This is a variable watcher function that writes NEW-VALUE to the saved
-videos file whenever `yeetube-saved-videos' changes.  _SYMBOL is the
-variable being watched, _WHERE indicates the type of change, and
-_ENVIRONMENT is the lexical environment."
-  (let ((file-path (concat user-emacs-directory "yeetube")))
-    (with-temp-buffer
-      (insert (pp-to-string new-value))
-      (write-region (point-min) (point-max) file-path))))
+SYMBOL-NAME is the name of the symbol to update.
+NEW-VALUE is the new value for the symbol.
+OPERATION is the operation to perform.
+WHERE indicates where in the buffer the update should happen."
+  (with-temp-buffer (find-file (concat user-emacs-directory "yeetube"))
+		    (erase-buffer)
+		    (setf yeetube-saved-videos new-value)
+		    (insert (pp-to-string yeetube-saved-videos))
+		    (save-buffer)
+		    (kill-buffer)))
 
 (defvar yeetube-filter-code-alist
   '(("Relevance" . "EgIQAQ%253D%253D")
@@ -358,7 +352,7 @@ _ENVIRONMENT is the lexical environment."
 				#'pop-to-buffer-same-window
 			      #'pop-to-buffer)))
     (unwind-protect
-        (if-let* ((err (plist-get status :error)))
+        (if-let* ((err (plist-get :error status)))
             (message "Error %s in retrieving yeetube results: %S" (car err) (cdr err))
           (with-temp-buffer
             (set-buffer-multibyte t)
@@ -378,33 +372,29 @@ _ENVIRONMENT is the lexical environment."
            (url-retrieve url #'yeetube--callback nil 'silent 'inhibit-cookies))
 	(url-retrieve url #'yeetube--callback nil 'silent 'inhibit-cookies)))))
 
-(defun yeetube--extract-image (status)
-  "Extract thumbnail image from the current URL callback buffer.
-Return the image sized per `yeetube-thumbnail-size', or nil on error."
-  (unless (plist-get status :error)
-    (when-let* ((handle (mm-dissect-buffer t))
-                (image (mm-get-image handle)))
-      (setf (image-property image :max-width) (car yeetube-thumbnail-size)
-            (image-property image :max-height) (cdr yeetube-thumbnail-size))
-      image)))
-
 (defun yeetube--image-callback (status entry buffer)
   "Yeetube callback for thumbnail images handling STATUS.
 Image is inserted in BUFFER for ENTRY."
-  (let* ((url-buffer (current-buffer))
-         (image (yeetube--extract-image status)))
-    (kill-buffer url-buffer)
-    (when image
-      (when-let* ((vec (cadr (assoc (car entry) yeetube-content))))
-        (aset vec 0 (propertize (aref vec 0) 'display image)))
-      (when (get-buffer buffer)
-        (with-current-buffer buffer
-          (with-silent-modifications
-            (save-excursion
-              (goto-char (point-min))
-              (when (search-forward (format "[[%s.jpg]]" (car entry)) nil t)
-                (add-text-properties (match-beginning 0) (match-end 0)
-                                     `(display ,image))))))))))
+  (let ((url-buffer (current-buffer)))
+    (unwind-protect
+        (if-let ((err (plist-get status :error)))
+            (message "Error %s in retrieving a thumbnail: %S" (car err) (cdr err))
+          (if-let ((handle (mm-dissect-buffer t))
+                   (image (mm-get-image handle)))
+              (progn
+                (setf (image-property image :max-width) (car yeetube-thumbnail-size)
+                      (image-property image :max-height) (cdr yeetube-thumbnail-size))
+                ;; Debugging Statement
+                ;; (message "Retrieved and processing image for %s" (plist-get entry :title))
+                (with-current-buffer buffer
+                  (with-silent-modifications
+                    (save-excursion
+                      (goto-char (point-min))
+                      (search-forward (format "[[%s.jpg]]" (car entry)))
+                      ;; Ensure to remove the placeholder text
+                      (delete-region (match-beginning 0) (match-end 0))
+                      (insert-image image))))))
+	  (kill-buffer url-buffer)))))
 
 (defun yeetube--retrieve-thumbnail (url str buffer)
   "Retrieve thumbnail from URL and show it in place of STR in BUFFER."
@@ -460,7 +450,7 @@ Image is inserted in BUFFER for ENTRY."
   (yeetube-display-content-from-url (format "https://youtube.com/%s/streams" channel-id)))
 
 (defun yeetube-channel-search (channel-id query)
-  "Search channel with CHANNEL-ID for videos matching QUERY."
+  "Search channel with CHANNEL-ID for videoes matching QUERY."
   (interactive (list (yeetube-channel-id-at-point) (yeetube-read-query)))
   (yeetube-display-content-from-url
    (format "https://youtube.com/%s/search?query=%s"
@@ -516,8 +506,6 @@ Image is inserted in BUFFER for ENTRY."
   "Get content from youtube."
   (setf yeetube-content nil)
   (goto-char (point-min))
-  (search-forward "ytInitialData")
-  (search-forward "\"contents\"")
   (let ((count 0)
         (result-rx
 	 (rx "\"" (or "video" (and (or "playlist" "compact") (? "Video"))) "Renderer\""))
@@ -580,7 +568,10 @@ Image is inserted in BUFFER for ENTRY."
 
 (add-variable-watcher 'yeetube-saved-videos #'yeetube-update-saved-videos-list)
 
-;; Yeetube Download:
+;; Yeetube Downlaod:
+
+(defvar yeetube-ytdlp (executable-find "yt-dlp")
+  "Path for yt-dlp executable.")
 
 ;;;###autoload
 (defun yeetube-download-change-directory ()
@@ -603,16 +594,16 @@ Image is inserted in BUFFER for ENTRY."
 Optional values:
  NAME for custom file name.
  AUDIO-FORMAT to extract and keep contents as specified audio-format only."
-  (unless yeetube-ytdlp-program
-    (error "Executable for yt-dlp not found. Please set yeetube-ytdlp-program"))
-  (let* ((tor-command (when yeetube-enable-tor yeetube-torsocks-program))
+  (unless (executable-find "yt-dlp")
+    (error "Executable for yt-dlp not found.  Please install yt-dlp"))
+  (let* ((tor-command (when yeetube-enable-tor (executable-find "torsocks")))
          (name-command (when name (format "-o %s" (shell-quote-argument name))))
          (format-command (when audio-format
 			   (format "--extract-audio --audio-format %s"
 				   (shell-quote-argument audio-format))))
          (command (mapconcat 'identity (delq nil
 					     (list tor-command
-						   yeetube-ytdlp-program
+						   (executable-find "yt-dlp")
 						   (shell-quote-argument url)
 						   name-command format-command))
 			     " ")))
@@ -626,6 +617,8 @@ Content will be downloaded at `yeetube-download-directory'.
 Optionally, provide custom own URL."
   (interactive)
   (save-excursion
+    ;; When point is on thumbnail, id will be nil.
+    (and (null (tabulated-list-get-id)) (end-of-line))
     (let* ((id (tabulated-list-get-id))
 	   (entry-content (cadr (assoc id yeetube-content)))
 	   (type (aref entry-content (- (length entry-content) 1)))
@@ -682,7 +675,7 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
   "v" #'yeetube-mpv-toggle-video
   "V" #'yeetube-mpv-toggle-no-video-flag
   "s" #'yeetube-save-video
-  "L" #'yeetube-channel-streams
+  "S" #'yeetube-channel-streams
   "P" #'yeetube-play-saved-video
   "r" #'yeetube-replay
   "T" #'yeetube-mpv-toggle-torsocks
@@ -691,9 +684,8 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
 
 (defun yeetube--sort-views (a b)
   "Sort entries A and B by view count."
-  (let* ((idx (if yeetube-display-thumbnails-p 2 1))
-         (views-a (string-to-number (replace-regexp-in-string "," "" (aref (cadr a) idx))))
-         (views-b (string-to-number (replace-regexp-in-string "," "" (aref (cadr b) idx)))))
+  (let ((views-a (string-to-number (replace-regexp-in-string "," "" (aref (cadr a) 2))))
+        (views-b (string-to-number (replace-regexp-in-string "," "" (aref (cadr b) 2)))))
     (< views-a views-b)))
 
 (defun yeetube--duration-to-seconds (duration)
@@ -708,9 +700,8 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
 
 (defun yeetube--sort-duration (a b)
   "Sort entries A and B by duration."
-  (let* ((idx (if yeetube-display-thumbnails-p 3 2))
-         (duration-a (yeetube--duration-to-seconds (aref (cadr a) idx)))
-         (duration-b (yeetube--duration-to-seconds (aref (cadr b) idx))))
+  (let ((duration-a (yeetube--duration-to-seconds (aref (cadr a) 3)))
+        (duration-b (yeetube--duration-to-seconds (aref (cadr b) 3))))
     (< duration-a duration-b)))
 
 (defun yeetube--parse-relative-date (date)
@@ -732,16 +723,15 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
 
 (defun yeetube--sort-date (a b)
   "Sort entries A and B by relative date."
-  (let* ((idx (if yeetube-display-thumbnails-p 4 3))
-         (date-a (yeetube--parse-relative-date (aref (cadr a) idx)))
-         (date-b (yeetube--parse-relative-date (aref (cadr b) idx))))
+  (let ((date-a (yeetube--parse-relative-date (aref (cadr a) 4)))
+        (date-b (yeetube--parse-relative-date (aref (cadr b) 4))))
     (< date-a date-b)))
 
 (defun yeetube--tabulated-list-format (thumbnail-p)
   "Return tabulated-list format vector.
 
 If THUMBNAIL-P is non-nil, add thumbnail."
-  (let ((list-format `[("Thumbnail"  ,(ceiling (/ (float (car yeetube-thumbnail-size)) (frame-char-width))) nil)
+  (let ((list-format `[("Thumbnail"  ,(/ (window-width) 10) nil)
 		       ("Title" ,(/ (window-width) 3) t)
 		       ("Views" ,(/ (window-width) 10) yeetube--sort-views)
 		       ("Duration" ,(/ (window-width) 10)  yeetube--sort-duration)
@@ -750,9 +740,9 @@ If THUMBNAIL-P is non-nil, add thumbnail."
     (if thumbnail-p list-format (cl-subseq list-format 1))))
 
 (defun yeetube-tabulated-list (&optional thumbnail-p)
-  "Return a tabulated list, adjusted for `window-width'.
+  "Return a tabulated list, adjusted for `window-width'
 
-If THUMBNAIL-P is non-nil, display thumbnails."
+If THUMBNAIL-P is non-nil, display thumbnails.."
   (let ((thumbnail-p (or thumbnail-p yeetube-display-thumbnails-p)))
     (setf tabulated-list-format (yeetube--tabulated-list-format thumbnail-p)
 	  tabulated-list-entries yeetube-content
@@ -763,7 +753,6 @@ If THUMBNAIL-P is non-nil, display thumbnails."
 (define-derived-mode yeetube-mode tabulated-list-mode "Yeetube"
   "Yeetube mode."
   :keymap yeetube-mode-map
-  (setq-local truncate-string-ellipsis " ")
   (yeetube-tabulated-list)
   (setq-local yeetube-mpv-show-status t)
   (display-line-numbers-mode 0)
